@@ -1,12 +1,13 @@
 class FiberData:
-    type = 'fiber'
+    service_type = 'fiber'
 
     def __init__(
             self, order_id, phone_number, iban, email, service_address, service_city,
             service_zip, service_subdivision, service_subdivision_code, shipment_address, shipment_city, shipment_zip,
             shipment_subdivision, previous_service, previous_provider, previous_internal_provider, product,
             previous_owner_vat, previous_owner_name, previous_owner_surname, notes, adsl_coverage, mm_fiber_coverage,
-            vdf_fiber_coverage, change_address, old_contract_pon="", old_contract_fiber_speed=""):
+            vdf_fiber_coverage, type, previous_contract_address="", previous_contract_pon="",
+            previous_contract_phone="", previous_contract_fiber_speed=""):
 
         # Common to all Tickets
         self.order_id = order_id
@@ -35,8 +36,10 @@ class FiberData:
         self.adsl_coverage = adsl_coverage
         self.mm_fiber_coverage = mm_fiber_coverage
         self.vdf_fiber_coverage = vdf_fiber_coverage
-        self.change_address = change_address
+        self.type = type
+        self.previous_contract_address = previous_contract_address
+        self.previous_contract_phone = previous_contract_phone
 
         # Exclusive to Fiber Tickets
-        self.old_contract_pon = old_contract_pon
-        self.old_contract_fiber_speed = old_contract_fiber_speed
+        self.previous_contract_pon = previous_contract_pon
+        self.previous_contract_fiber_speed = previous_contract_fiber_speed
