@@ -10,15 +10,15 @@ class FiberDynamicFields(InternetDynamicFields):
         """ Return list of OTRS DynamicFields to create a OTRS Process Ticket from service data and customer data.
         Return only the specifics fields of Fiber Ticket. """
         return [
-            self._df_old_contract_pon(),
-            self._df_old_contract_fiber_speed()
+            self._df_previous_contract_pon(),
+            self._df_previous_contract_fiber_speed()
         ]
 
-    def _df_old_contract_pon(self):
-        return DynamicField(name="ponAntic", value=self.service_data.old_contract_pon)
+    def _df_previous_contract_pon(self):
+        return DynamicField(name="IDtryton", value=self.service_data.previous_contract_pon)
 
-    def _df_old_contract_fiber_speed(self):
+    def _df_previous_contract_fiber_speed(self):
         return DynamicField(
             name="velocitatSollicitadaContracteAnteriorCU",
-            value=self.service_data.old_contract_fiber_speed
+            value=self.service_data.previous_contract_fiber_speed
         )
