@@ -12,6 +12,8 @@ class InternetDynamicFields(ProvisionDynamicFields):
             self._econtract_id(),
             self._previous_service(),
             self._previous_provider(),
+            self._previous_contract_address(),
+            self._previous_contract_phone(),
             self._landline_number(),
             self._service_address(),
             self._service_city(),
@@ -40,12 +42,12 @@ class InternetDynamicFields(ProvisionDynamicFields):
 
     def _previous_provider(self):
         provider = None
-        if self.service_data.change_address == "no":
+        if self.service_data.type != "location_change":
             provider = self.service_data.previous_provider
         return DynamicField(name="proveidorPrevi", value=provider)
 
     def _landline_number(self):
-        return DynamicField(name='telefonFixVell', value=self.service_data.phone_number)
+        return DynamicField(name="telefonFixVell", value=self.service_data.phone_number)
 
     def _service_address(self):
         return DynamicField(name="direccioServei", value=self.service_data.service_address)
@@ -92,8 +94,17 @@ class InternetDynamicFields(ProvisionDynamicFields):
             value=self.service_data.vdf_fiber_coverage
         )
 
+    def _previous_contract_phone(self):
+        return DynamicField(name="telefonFixAntic", value=self.service_data.previous_contract_phone)
+
+    def _previous_contract_address(self):
+        return DynamicField(name="direccioServeiAntic", value=self.service_data.previous_contract_address)
+
     def _change_address(self):
-        return DynamicField(name="canviUbicacioMateixTitular", value=self.service_data.change_address)
+        change_address = None
+        if self.service_data.type == "location_change":
+            change_address = "location_change"
+        return DynamicField(name="canviUbicacioMateixTitular", value=change_address)
 
     def _change_address_provider(self):
         return DynamicField(name="proveidorPreviCU", value=self.service_data.previous_internal_provider)
