@@ -1,5 +1,5 @@
 class MobileData:
-    type = 'mobile'
+    service_type = 'mobile'
 
     def __init__(
         self, order_id, phone_number, iban, email, sc_icc, icc,
