@@ -14,14 +14,14 @@ class TicketFactory(object):
 
     def build(self):
         """ Create a OTRS Process Ticket with the information of the ServiceData and return it. """
-        if self.service_data.type == 'adsl':
+        if self.service_data.service_type == 'adsl':
             TicketClass = ADSLTicket
-        elif self.service_data.type == 'fiber':
+        elif self.service_data.service_type == 'fiber':
             TicketClass = FiberTicket
-        elif self.service_data.type == 'mobile':
+        elif self.service_data.service_type == 'mobile':
             TicketClass = MobileTicket
         else:
-            raise ServiceTypeNotAllowedError(self.service_data.order_id, self.service_data.type)
+            raise ServiceTypeNotAllowedError(self.service_data.order_id, self.service_data.service_type)
 
         return TicketClass(
             service_data=self.service_data,
