@@ -38,7 +38,7 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'zip',
             'subdivision'])
 
-        mobile_data.type = 'mobile'
+        mobile_data.service_type = 'mobile'
 
         otrs_process_ticket = Mock(spec=['id'])
         otrs_process_ticket.id = 234
@@ -69,6 +69,8 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'previous_owner_surname',
             'previous_owner_vat',
             'previous_service',
+            'previous_contract_address',
+            'previous_contract_phone',
             'service_address',
             'service_city',
             'service_zip',
@@ -82,14 +84,14 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'adsl_coverage',
             'mm_fiber_coverage',
             'vdf_fiber_coverage',
-            'change_address',
+            'type',
             'landline_phone_number',
             'product',
             'previous_internal_provider',
         ])
         customer_data = Mock(spec=['id', 'first_name', 'name', 'vat_number', 'phone'])
 
-        service_data.type = 'adsl'
+        service_data.service_type = 'adsl'
 
         otrs_process_ticket = Mock(spec=['id'])
         otrs_process_ticket.id = 234
@@ -112,8 +114,10 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
     def test_create_fiber_ticket_factory(self, MockOTRSClient):
         service_data = Mock(spec=[
             'order_id',
-            'old_contract_pon',
-            'old_contract_fiber_speed',
+            'previous_contract_pon',
+            'previous_contract_fiber_speed',
+            'previous_contract_address',
+            'previous_contract_phone',
             'type',
             'iban',
             'email',
@@ -136,13 +140,12 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'adsl_coverage',
             'mm_fiber_coverage',
             'vdf_fiber_coverage',
-            'change_address',
             'product',
             'previous_internal_provider',
         ])
         customer_data = Mock(spec=['id', 'first_name', 'name', 'vat_number', 'phone'])
 
-        service_data.type = 'fiber'
+        service_data.service_type = 'fiber'
 
         otrs_process_ticket = Mock(spec=['id'])
         otrs_process_ticket.id = 234
