@@ -22,12 +22,13 @@ class UpdateTicketWithCoverageTicketInfoTestCase(unittest.TestCase):
         'OTRS_URL': URL
     })
     @patch('otrs_somconnexio.client.Client', return_value=Mock(
-        spec=['session_create', 'ticket_update']
+        spec=['session_create', 'ticket_update', 'ticket_search', 'ticket_get_by_id']
     ))
     @patch('otrs_somconnexio.otrs_models.abstract_article.Article')
     def test_run(self, MockArticle, MockClient):
-        ticket_id = 123
-
+        process_ticket_id = 123
+        coverage_ticket_id = 456
+        email = 'email@email.com'
         ticket = Mock(spec=['response'])
         ticket.response = Mock(spec=['dynamic_field_get'])
 
@@ -40,11 +41,25 @@ class UpdateTicketWithCoverageTicketInfoTestCase(unittest.TestCase):
         coverage_article = object()
         MockArticle.return_value = coverage_article
 
-        UpdateProcessTicketWithCoverageTicketsInfoService(ticket_id, [coverage_ticket]).run()
+        def ticket_search_side_effect(dynamic_fields):
+            if len(dynamic_fields) != 2:
+                return []
+            if dynamic_fields[0].search_patterns == ["Process-be8cf222949132c9fae1bb74615a5ae4"] \
+                and dynamic_fields[1].search_patterns == [email]:
+                    return [coverage_ticket_id]
+            return []
 
-        MockClient.return_value.ticket_update.assert_called_with(ticket_id, coverage_article, dynamic_fields=[])
+        MockClient.return_value.ticket_search.side_effect = ticket_search_side_effect
+        MockClient.return_value.ticket_get_by_id.return_value = ticket.response
+
+        UpdateProcessTicketWithCoverageTicketsInfoService(process_ticket_id).run(email)
+
+        MockClient.return_value.ticket_get_by_id.assert_called_with(coverage_ticket_id, dynamic_fields=True)
+
+        MockClient.return_value.ticket_update.assert_called_with(process_ticket_id, coverage_article, dynamic_fields=[])
         MockArticle.assert_called_with({
             "Subject": "Sol·licitud cobertura",
             "Body": "tipusVia: foo\nnomVia: foo\nnumero: foo\nbloc: foo\nportal: foo\npis: foo\nescala: foo\nporta: foo\npoblacioServei: foo\nprovinciaServei: foo\ncodiProvinciaServei: foo\nCPservei: foo\naltresCobertura: foo\ncoberturaADSL: foo\ncoberturaFibraMM: foo\ncoberturaFibraVdf: foo\nIDhogar: foo\n",  # noqa
-            "ContentType": "text/plain; charset=utf8"
+            "ContentType": "text/plain; charset=utf8",
+            "IsVisibleForCustomer": "1",
         })
