@@ -31,7 +31,7 @@ class ADSLDataTestCase(unittest.TestCase):
             adsl_coverage=None,
             mm_fiber_coverage=None,
             vdf_fiber_coverage=None,
-            change_address="no",
+            type="location_change",
             landline_phone_number="landline_phone_number",
             product="product"
         )
