@@ -80,6 +80,8 @@ class ADSLTicketTestCase(unittest.TestCase):
             'previous_owner_vat',
             'previous_owner_name',
             'previous_owner_surname',
+            'previous_contract_address',
+            'previous_contract_phone',
             'service_address',
             'service_city',
             'service_zip',
@@ -93,7 +95,7 @@ class ADSLTicketTestCase(unittest.TestCase):
             'adsl_coverage',
             'mm_fiber_coverage',
             'vdf_fiber_coverage',
-            'change_address',
+            'type',
             'landline_phone_number',
             'product',
             'previous_internal_provider',
