@@ -31,10 +31,12 @@ class FiberDataTestCase(unittest.TestCase):
             adsl_coverage=None,
             mm_fiber_coverage=None,
             vdf_fiber_coverage=None,
-            change_address="no",
+            type="new",
             product="product",
-            old_contract_fiber_speed="100Mb",
-            old_contract_pon="VDF0001"
+            previous_contract_address="Old street",
+            previous_contract_phone="62626826",
+            previous_contract_fiber_speed="100Mb",
+            previous_contract_pon="VDF0001"
         )
 
         self.assertIsInstance(fiber_data, FiberData)
