@@ -26,8 +26,10 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         ])
         self.service_data = Mock(spec=[
             'order_id',
-            'old_contract_pon',
-            'old_contract_fiber_speed',
+            'previous_contract_address',
+            'previous_contract_phone',
+            'previous_contract_pon',
+            'previous_contract_fiber_speed',
             'iban',
             'email',
             'phone_number',
@@ -49,7 +51,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             'adsl_coverage',
             'mm_fiber_coverage',
             'vdf_fiber_coverage',
-            'change_address',
+            'type',
             'product',
             'previous_internal_provider',
         ])
@@ -68,7 +70,9 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["ProcessManagementProcessID"], "ADSLProcessID")
 
-    def test_pon_field(self):
+    def test_previous_phone_field(self):
+        self.service_data.previous_contract_phone = "666666666"
+
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
@@ -78,11 +82,45 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(
-            dynamic_fields_dct["ponAntic"],
-            self.service_data.old_contract_pon
+            dynamic_fields_dct["telefonFixAntic"],
+            self.service_data.previous_contract_phone
         )
 
-    def test_old_contract_fiber_speed_field(self):
+    def test_previous_address_field(self):
+        self.service_data.previous_contract_address = "Old street"
+
+        dynamic_fields = FiberDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.adsl_otrs_process_id,
+            self.adsl_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(
+            dynamic_fields_dct["direccioServeiAntic"],
+            self.service_data.previous_contract_address
+        )
+
+    def test_pon_field(self):
+        self.service_data.previous_contract_pon = "8282"
+
+        dynamic_fields = FiberDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.adsl_otrs_process_id,
+            self.adsl_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(
+            dynamic_fields_dct["IDtryton"],
+            self.service_data.previous_contract_pon
+        )
+
+    def test_previous_contract_fiber_speed_field(self):
+        self.service_data.previous_contract_fiber_speed = "100Mb"
+
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
@@ -93,7 +131,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(
             dynamic_fields_dct["velocitatSollicitadaContracteAnteriorCU"],
-            self.service_data.old_contract_fiber_speed
+            self.service_data.previous_contract_fiber_speed
         )
 
     def test_activity_id_field(self):
@@ -212,7 +250,6 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
 
     def test_previous_provider_field(self):
         self.service_data.previous_provider = "SomConnexio"
-        self.service_data.change_address = "no"
 
         dynamic_fields = FiberDynamicFields(
             self.service_data,
@@ -432,32 +469,6 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["coberturaFibraVdf"], "FibraVdf")
 
-    def test_change_address_field(self):
-        self.service_data.change_address = "yes"
-
-        dynamic_fields = FiberDynamicFields(
-            self.service_data,
-            self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
-        ).all()
-
-        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["canviUbicacioMateixTitular"], "yes")
-
-    def test_change_address_field_doesnt_set(self):
-        self.service_data.change_address = "no"
-
-        dynamic_fields = FiberDynamicFields(
-            self.service_data,
-            self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
-        ).all()
-
-        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["canviUbicacioMateixTitular"], "no")
-
     def test_product_field(self):
         self.service_data.product = "FIBRA100"
 
@@ -485,7 +496,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["proveidorPreviCU"], "SC-MM")
 
     def test_previous_provider_not_exists_in_change_address(self):
-        self.service_data.change_address = True
+        self.service_data.type = 'location_change'
 
         dynamic_fields = FiberDynamicFields(
             self.service_data,
