@@ -11,6 +11,7 @@ class MobileDataTestCase(unittest.TestCase):
             order_id=123,
             phone_number="666666666",
             iban="ES6621000418401234567891",
+            email="test@test.com",
             previous_provider="SC",
             previous_owner_vat="740227654G",
             previous_owner_name="name",
@@ -18,7 +19,8 @@ class MobileDataTestCase(unittest.TestCase):
             portability=False,
             sc_icc="123456789",
             icc=None,
-            product="product"
+            product="product",
+            notes="Mobile crm lead line",
         )
 
         self.assertIsInstance(mobile_data, MobileData)
